@@ -15,6 +15,21 @@
 #include <iostream>
 #include <stdlib.h>
 
+template <typename T>
+int
+assertEquals(T expected, T actual)
+{
+    if (expected != actual) {
+        std::cerr << "assertEquals failed" << std::endl;
+        std::cerr << "expected: " << expected << std::endl;
+        std::cerr << "actual  : " << actual << std::endl;
+        
+        return EXIT_FAILURE;
+    }
+    
+    return EXIT_SUCCESS;
+}
+
 int
 assertEquals(const std::string &expected, const std::string &actual)
 {
@@ -29,18 +44,4 @@ assertEquals(const std::string &expected, const std::string &actual)
     return EXIT_SUCCESS;
 }
 
-int
-assertEquals(bool expected, bool actual)
-{
-    if (expected != actual) {
-        std::cerr << "assertEquals failed" << std::endl;
-        std::cerr << "expected: " << expected << std::endl;
-        std::cerr << "actual  : " << actual << std::endl;
-        
-        return EXIT_FAILURE;
-    }
-    
-    return EXIT_SUCCESS;
-}
-
 #endif /*_ASSERTTEST_H_*/
