@@ -56,7 +56,9 @@
      NONSENSITIVE_T = 272,
      KEY = 273,
      STRINGDEF = 274,
-     VARUSE = 275
+     REGEXPNOPREPROC = 275,
+     VARUSE = 276,
+     REGEXPDEF = 277
    };
 #endif
 /* Tokens.  */
@@ -77,14 +79,16 @@
 #define NONSENSITIVE_T 272
 #define KEY 273
 #define STRINGDEF 274
-#define VARUSE 275
+#define REGEXPNOPREPROC 275
+#define VARUSE 276
+#define REGEXPDEF 277
 
 
 
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 69 "./langdefparser.yy"
+#line 73 "./langdefparser.yy"
 {
   int tok ; /* command */
   bool booloption ;
@@ -95,11 +99,13 @@ typedef union YYSTYPE
   class StateLangElem *statelangelem;
   class StateStartLangElem *statestartlangelem;
   class LangElems *langelems;
+  class NamedSubExpsLangElem *namedsubexpslangelem;
   struct Key *key;
+  class ElementNamesList *keys;
   int flag ;
 }
-/* Line 1529 of yacc.c.  */
-#line 103 "langdefparser.h"
+/* Line 1489 of yacc.c.  */
+#line 109 "langdefparser.h"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
