@@ -137,7 +137,7 @@
 #line 1 "./outlangdefparser.yy"
 
 /*
- * Copyright (C) 1999-2005 Lorenzo Bettini <http://www.lorenzobettini.it>
+ * Copyright (C) 1999-2007 Lorenzo Bettini <http://www.lorenzobettini.it>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -161,8 +161,6 @@
 #include <iostream>
 #include <string>
 
-#include "my_sstream.h"
-
 #include "messages.h"
 #include "parsestruct.h"
 #include "outlangdefscanner.h"
@@ -205,7 +203,7 @@ const char *anchor_vars[] = {"linenum", "infilename", "infile", 0};
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 51 "./outlangdefparser.yy"
+#line 49 "./outlangdefparser.yy"
 {
   int tok ; /* command */
   bool booloption ;
@@ -213,7 +211,7 @@ typedef union YYSTYPE
   int flag ;
 }
 /* Line 187 of yacc.c.  */
-#line 217 "outlangdefparser.cc"
+#line 215 "outlangdefparser.cc"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -226,7 +224,7 @@ typedef union YYSTYPE
 
 
 /* Line 216 of yacc.c.  */
-#line 230 "outlangdefparser.cc"
+#line 228 "outlangdefparser.cc"
 
 #ifdef short
 # undef short
@@ -522,10 +520,10 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,    67,    67,    70,    71,    74,    81,    87,    93,    99,
-     105,   111,   117,   123,   129,   135,   141,   147,   153,   159,
-     170,   176,   182,   188,   193,   199,   202,   204,   207,   214,
-     221,   224,   226,   229
+       0,    65,    65,    68,    69,    72,    79,    85,    91,    97,
+     103,   109,   115,   121,   127,   133,   139,   145,   151,   157,
+     168,   174,   180,   186,   191,   197,   200,   202,   205,   212,
+     219,   222,   224,   227
 };
 #endif
 
@@ -1467,7 +1465,7 @@ yyreduce:
   switch (yyn)
     {
         case 5:
-#line 75 "./outlangdefparser.yy"
+#line 73 "./outlangdefparser.yy"
     {
     textstyles->docTemplate = DocTemplate(*(yyvsp[(2) - (4)].string), *(yyvsp[(3) - (4)].string));
     delete (yyvsp[(2) - (4)].string);
@@ -1476,7 +1474,7 @@ yyreduce:
     break;
 
   case 6:
-#line 82 "./outlangdefparser.yy"
+#line 80 "./outlangdefparser.yy"
     {
     textstyles->starting_template = *(yyvsp[(2) - (2)].string);
     delete (yyvsp[(2) - (2)].string);
@@ -1484,7 +1482,7 @@ yyreduce:
     break;
 
   case 7:
-#line 88 "./outlangdefparser.yy"
+#line 86 "./outlangdefparser.yy"
     {
     textstyles->style_separator = *(yyvsp[(2) - (2)].string);
     delete (yyvsp[(2) - (2)].string);
@@ -1492,7 +1490,7 @@ yyreduce:
     break;
 
   case 8:
-#line 94 "./outlangdefparser.yy"
+#line 92 "./outlangdefparser.yy"
     {
   textstyles->bold = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(2) - (2)].string);
@@ -1500,7 +1498,7 @@ yyreduce:
     break;
 
   case 9:
-#line 100 "./outlangdefparser.yy"
+#line 98 "./outlangdefparser.yy"
     {
   textstyles->italics = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(2) - (2)].string);
@@ -1508,7 +1506,7 @@ yyreduce:
     break;
 
   case 10:
-#line 106 "./outlangdefparser.yy"
+#line 104 "./outlangdefparser.yy"
     {
   textstyles->underline = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(2) - (2)].string);
@@ -1516,7 +1514,7 @@ yyreduce:
     break;
 
   case 11:
-#line 112 "./outlangdefparser.yy"
+#line 110 "./outlangdefparser.yy"
     {
   textstyles->fixed = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(2) - (2)].string);
@@ -1524,7 +1522,7 @@ yyreduce:
     break;
 
   case 12:
-#line 118 "./outlangdefparser.yy"
+#line 116 "./outlangdefparser.yy"
     {
   textstyles->notfixed = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(2) - (2)].string);
@@ -1532,7 +1530,7 @@ yyreduce:
     break;
 
   case 13:
-#line 124 "./outlangdefparser.yy"
+#line 122 "./outlangdefparser.yy"
     {
   textstyles->color = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(2) - (2)].string);
@@ -1540,7 +1538,7 @@ yyreduce:
     break;
 
   case 14:
-#line 130 "./outlangdefparser.yy"
+#line 128 "./outlangdefparser.yy"
     {
   textstyles->bg_color = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(2) - (2)].string);
@@ -1548,7 +1546,7 @@ yyreduce:
     break;
 
   case 15:
-#line 136 "./outlangdefparser.yy"
+#line 134 "./outlangdefparser.yy"
     {
   textstyles->onestyle = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(2) - (2)].string);
@@ -1556,7 +1554,7 @@ yyreduce:
     break;
 
   case 16:
-#line 142 "./outlangdefparser.yy"
+#line 140 "./outlangdefparser.yy"
     {
   textstyles->file_extension = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(2) - (2)].string);
@@ -1564,7 +1562,7 @@ yyreduce:
     break;
 
   case 17:
-#line 148 "./outlangdefparser.yy"
+#line 146 "./outlangdefparser.yy"
     {
   textstyles->refstyle.anchor = TextStyle(*(yyvsp[(2) - (2)].string), anchor_vars);
   delete (yyvsp[(2) - (2)].string);
@@ -1572,7 +1570,7 @@ yyreduce:
     break;
 
   case 18:
-#line 154 "./outlangdefparser.yy"
+#line 152 "./outlangdefparser.yy"
     {
   textstyles->line_prefix = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(2) - (2)].string);
@@ -1580,7 +1578,7 @@ yyreduce:
     break;
 
   case 19:
-#line 160 "./outlangdefparser.yy"
+#line 158 "./outlangdefparser.yy"
     {
   if (textstyles->refstyle.inline_reference.empty())
     textstyles->refstyle.inline_reference = TextStyle(*(yyvsp[(2) - (2)].string), reference_vars);
@@ -1593,7 +1591,7 @@ yyreduce:
     break;
 
   case 20:
-#line 171 "./outlangdefparser.yy"
+#line 169 "./outlangdefparser.yy"
     {
   textstyles->refstyle.inline_reference = TextStyle(*(yyvsp[(2) - (2)].string), reference_vars);
   delete (yyvsp[(2) - (2)].string);
@@ -1601,7 +1599,7 @@ yyreduce:
     break;
 
   case 21:
-#line 177 "./outlangdefparser.yy"
+#line 175 "./outlangdefparser.yy"
     {
   textstyles->refstyle.postline_reference = TextStyle(*(yyvsp[(2) - (2)].string), reference_vars);
   delete (yyvsp[(2) - (2)].string);
@@ -1609,7 +1607,7 @@ yyreduce:
     break;
 
   case 22:
-#line 183 "./outlangdefparser.yy"
+#line 181 "./outlangdefparser.yy"
     {
   textstyles->refstyle.postdoc_reference = TextStyle(*(yyvsp[(2) - (2)].string), reference_vars);
   delete (yyvsp[(2) - (2)].string);
@@ -1617,21 +1615,21 @@ yyreduce:
     break;
 
   case 23:
-#line 189 "./outlangdefparser.yy"
+#line 187 "./outlangdefparser.yy"
     {
   textstyles->colorMap = colorMap;
 }
     break;
 
   case 24:
-#line 194 "./outlangdefparser.yy"
+#line 192 "./outlangdefparser.yy"
     {
   textstyles->charTranslator = charTranslator;
 }
     break;
 
   case 28:
-#line 208 "./outlangdefparser.yy"
+#line 206 "./outlangdefparser.yy"
     {
   (*colorMap)[*(yyvsp[(1) - (2)].string)] = *(yyvsp[(2) - (2)].string);
   delete (yyvsp[(1) - (2)].string);
@@ -1640,7 +1638,7 @@ yyreduce:
     break;
 
   case 29:
-#line 215 "./outlangdefparser.yy"
+#line 213 "./outlangdefparser.yy"
     {
   colorMap->setDefault(*(yyvsp[(2) - (2)].string));
   delete (yyvsp[(2) - (2)].string);
@@ -1648,7 +1646,7 @@ yyreduce:
     break;
 
   case 33:
-#line 230 "./outlangdefparser.yy"
+#line 228 "./outlangdefparser.yy"
     {
   charTranslator->set_translation(*(yyvsp[(1) - (2)].string), *(yyvsp[(2) - (2)].string));
   delete (yyvsp[(1) - (2)].string);
@@ -1658,7 +1656,7 @@ yyreduce:
 
 
 /* Line 1267 of yacc.c.  */
-#line 1662 "outlangdefparser.cc"
+#line 1660 "outlangdefparser.cc"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1872,26 +1870,17 @@ yyreturn:
 }
 
 
-#line 236 "./outlangdefparser.yy"
+#line 234 "./outlangdefparser.yy"
 
 
+extern int outlangdef_lex_destroy (void);
+
 void
 yyerror( const char *s )
 {
-  ostringstream str ;
-  str << outlang_parsestruct->file_name << ":" << outlang_parsestruct->line << ": " << s; // << ", in option declaration";
-  printError( str.str(), cerr ) ;
-  exit(EXIT_FAILURE);
+  exitError(s, outlang_parsestruct);
 }
 
-/*
-void
-yyerror( const string &s )
-{
-  yyerror(s.c_str());
-}
-*/
-
 TextStylesPtr
 parse_outlang_def()
 {
@@ -1902,6 +1891,10 @@ parse_outlang_def()
   outlangdef_parse();
   delete outlang_parsestruct;
   outlang_parsestruct = 0;
+
+  // release scanner memory
+  outlangdef_lex_destroy ();
+
   return textstyles;
 }
 
@@ -1916,6 +1909,10 @@ parse_outlang_def(const char *path, const char *name)
   outlangdef_parse();
   delete outlang_parsestruct;
   outlang_parsestruct = 0;
+
+  // release scanner memory
+  outlangdef_lex_destroy ();
+
   return textstyles;
 }
 
@@ -1932,6 +1929,10 @@ parse_outlang_def_file(const char *path, const char *name)
   outlangdef_parse();
   delete outlang_parsestruct;
   outlang_parsestruct = 0;
+
+  // release scanner memory
+  outlangdef_lex_destroy ();
+
   return textstyles;
 }
 
