@@ -29,6 +29,10 @@ class OutputBuffer : protected LineBuffer::PostContents
   private:
     LineBufferPtr linebuffer;
     OutputGenerator *outputGenerator;
+    /// whether to always flush after outputting something (default false)
+    bool alwaysFlush;
+    /// whether we're about to start a new line
+    bool newLine;
 
     void reset();
 
@@ -38,10 +42,16 @@ class OutputBuffer : protected LineBuffer::PostContents
     ~OutputBuffer();
 
     void output(const std::string &s);
+    /**
+     * Performs output and flushes
+     * @param s the string to output
+     */
+    void outputAndFlush(const std::string &s);
     void output_ln(const std::string &s);
     void output_postline(const std::string &s);
     void output_post(const std::string &s);
 
+    void setAlwaysFlush(bool f) { alwaysFlush = f; }
     void flush();
 
     void setOutputGenerator(OutputGenerator *og) { outputGenerator = og; }
