@@ -130,8 +130,6 @@
 #include <iostream>
 #include <string>
 
-#include "my_sstream.h"
-
 #include "generatorfactory.h"
 #include "colors.h"
 #include "keys.h"
@@ -158,6 +156,7 @@ static string bodyBgColor;
 
 extern int stylecsssc_lex() ;
 extern FILE *stylecsssc_in ;
+extern int stylecsssc_lex_destroy  (void);
 
 /// the global pointer to style constant for a specific element
 static StyleConstantsPtr currentStyleConstants;
@@ -188,7 +187,7 @@ static string currentBGColor;
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 64 "./stylecssparser.yy"
+#line 63 "./stylecssparser.yy"
 {
   int tok ; /* command */
   const std::string * string ; /* string : id, ... */
@@ -197,7 +196,7 @@ typedef union YYSTYPE
   KeyList *keylist;
 }
 /* Line 187 of yacc.c.  */
-#line 201 "stylecssparser.cc"
+#line 200 "stylecssparser.cc"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -210,7 +209,7 @@ typedef union YYSTYPE
 
 
 /* Line 216 of yacc.c.  */
-#line 214 "stylecssparser.cc"
+#line 213 "stylecssparser.cc"
 
 #ifdef short
 # undef short
@@ -499,9 +498,9 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,    79,    79,    80,    83,    84,    87,    91,    90,   135,
-     141,   149,   150,   153,   154,   155,   158,   163,   170,   175,
-     182,   183,   184,   185,   186,   187
+       0,    78,    78,    79,    82,    83,    86,    90,    89,   134,
+     140,   148,   149,   152,   153,   154,   157,   162,   169,   174,
+     181,   182,   183,   184,   185,   186
 };
 #endif
 
@@ -1416,12 +1415,12 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 79 "./stylecssparser.yy"
+#line 78 "./stylecssparser.yy"
     { /* allow empty files */ }
     break;
 
   case 7:
-#line 91 "./stylecssparser.yy"
+#line 90 "./stylecssparser.yy"
     {
                printSequence( (yyvsp[(1) - (1)].keylist) ) ;
                printMessage_noln( ": " ) ;
@@ -1432,7 +1431,7 @@ yyreduce:
     break;
 
   case 8:
-#line 99 "./stylecssparser.yy"
+#line 98 "./stylecssparser.yy"
     {
                printMessage_noln(" color: " + currentColor + " ") ;
                if (currentBGColor != "")
@@ -1446,11 +1445,11 @@ yyreduce:
                 // check whether it's the body specification
                 if (Utils::tolower(key) == "body") {
                   updateBgColor(currentBGColor);
-                  
+
                   // notice that for text style specification for the body, the background
                   // is assumed for the entire document and not for the normal text
                   // following the semantics of css
-                  
+
                   // avoid adding an empty style definition for normal
                   if (currentColor != "" || currentStyleConstants->size()) {
                     if (!generatorFactory->createGenerator(NORMAL, currentColor, "", currentStyleConstants)) {
@@ -1470,7 +1469,7 @@ yyreduce:
     break;
 
   case 9:
-#line 136 "./stylecssparser.yy"
+#line 135 "./stylecssparser.yy"
     {
               (yyvsp[(1) - (3)].keylist)->push_back(*(yyvsp[(3) - (3)].string));
               (yyval.keylist) = (yyvsp[(1) - (3)].keylist);
@@ -1479,7 +1478,7 @@ yyreduce:
     break;
 
   case 10:
-#line 142 "./stylecssparser.yy"
+#line 141 "./stylecssparser.yy"
     {
               (yyval.keylist) = new KeyList;
               (yyval.keylist)->push_back(*(yyvsp[(1) - (1)].string));
@@ -1488,12 +1487,12 @@ yyreduce:
     break;
 
   case 11:
-#line 149 "./stylecssparser.yy"
+#line 148 "./stylecssparser.yy"
     {}
     break;
 
   case 16:
-#line 159 "./stylecssparser.yy"
+#line 158 "./stylecssparser.yy"
     {
           currentColor = *(yyvsp[(1) - (1)].string);
           delete (yyvsp[(1) - (1)].string);
@@ -1501,7 +1500,7 @@ yyreduce:
     break;
 
   case 17:
-#line 164 "./stylecssparser.yy"
+#line 163 "./stylecssparser.yy"
     {
           currentColor = *(yyvsp[(1) - (1)].string);
           delete (yyvsp[(1) - (1)].string);
@@ -1509,7 +1508,7 @@ yyreduce:
     break;
 
   case 18:
-#line 171 "./stylecssparser.yy"
+#line 170 "./stylecssparser.yy"
     {
           currentBGColor = *(yyvsp[(1) - (1)].string);
           delete (yyvsp[(1) - (1)].string);
@@ -1517,7 +1516,7 @@ yyreduce:
     break;
 
   case 19:
-#line 176 "./stylecssparser.yy"
+#line 175 "./stylecssparser.yy"
     {
           currentBGColor = *(yyvsp[(1) - (1)].string);
           delete (yyvsp[(1) - (1)].string);
@@ -1525,38 +1524,38 @@ yyreduce:
     break;
 
   case 20:
-#line 182 "./stylecssparser.yy"
+#line 181 "./stylecssparser.yy"
     { printMessage_noln( " bold" ) ; currentStyleConstants->push_back(ISBOLD); }
     break;
 
   case 21:
-#line 183 "./stylecssparser.yy"
+#line 182 "./stylecssparser.yy"
     { printMessage_noln( " italics" ) ; currentStyleConstants->push_back(ISITALIC); }
     break;
 
   case 22:
-#line 184 "./stylecssparser.yy"
+#line 183 "./stylecssparser.yy"
     { printMessage_noln( " underline" ) ; currentStyleConstants->push_back(ISUNDERLINE); }
     break;
 
   case 23:
-#line 185 "./stylecssparser.yy"
+#line 184 "./stylecssparser.yy"
     { printMessage_noln( " fixed" ) ; currentStyleConstants->push_back(ISFIXED); }
     break;
 
   case 24:
-#line 186 "./stylecssparser.yy"
+#line 185 "./stylecssparser.yy"
     { printMessage_noln( " notfixed" ) ; currentStyleConstants->push_back(ISNOTFIXED); }
     break;
 
   case 25:
-#line 187 "./stylecssparser.yy"
+#line 186 "./stylecssparser.yy"
     { printMessage_noln( " noref" ) ; currentStyleConstants->push_back(ISNOREF); }
     break;
 
 
 /* Line 1267 of yacc.c.  */
-#line 1560 "stylecssparser.cc"
+#line 1559 "stylecssparser.cc"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1770,7 +1769,7 @@ yyreturn:
 }
 
 
-#line 190 "./stylecssparser.yy"
+#line 189 "./stylecssparser.yy"
 
 
 // string current_file; defined in styleparser
@@ -1789,22 +1788,24 @@ void parseCssStyles(const string &path, const string &name, GeneratorFactory *ge
   printMessage_noln( "Parsing ", cerr ) ;
   printMessage_noln (current_file, cerr);
   printMessage( " file ...", cerr ) ;
-  
+
   bodyBgColor = "";
-  
+
   yyparse() ;
-  
+
   bodyBgColor_ = bodyBgColor;
-  
+
   printMessage( "Parsing done!", cerr ) ;
   fclose(stylecsssc_in);
+
+  // release scanner memory
+  stylecsssc_lex_destroy();
 }
 
 void
 yyerror( char *s )
 {
   parseStyleError(s);
-  exit(EXIT_FAILURE);
 }
 
 void updateBgColor(const std::string &c)
